@@ -1,19 +1,20 @@
 package Locale::CLDR::Locales::Qu::Any;
 
 # This file auto generated
-#	on Wed 10 Feb  8:20:14 am GMT
+#	on Fri 29 Apr  7:22:10 pm GMT
 
 use version;
 
-our $VERSION = version->declare('v0.28.3');
+our $VERSION = version->declare('v0.29.0');
 
 use v5.10.1;
 use mro 'c3';
 use if $^V ge v5.12.0, feature => 'unicode_strings';
 
-use Moose;
+use Moo;
 
 extends('Locale::CLDR::Locales::Qu');
 
-no Moose;
-__PACKAGE__->meta->make_immutable;
+no Moo;
+
+1;
